@@ -1,13 +1,13 @@
 OC.L10N.register(
     "calendar",
     {
-    "Calendar" : "Kalenteri",
     "Provided email-address is not valid" : "Annettu sähköpostiosoite ei ole kelvollinen",
     "%s has published the calendar »%s«" : "%s on julkaissut kalenterin  »%s«",
     "Hello," : "Hei,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Halusimme ilmoittaa että %s on julkaissut kalenterin »%s«.",
     "Open »%s«" : "Avaa »%s«",
     "Cheers!" : "Kiitos!",
+    "Calendar" : "Kalenteri",
     "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
     "Previous day" : "Edellinen päivä",
     "Previous week" : "Edellinen viikko",
@@ -91,8 +91,6 @@ OC.L10N.register(
     "No match found" : "Ei tuloksia",
     "(organizer)" : "(järjestäjä)",
     "All day" : "Koko päivä",
-    "from" : "alkaen",
-    "to" : "päättyen",
     "never" : "ei koskaan",
     "after" : "jälkeen",
     "Repeat" : "Kertaa",
@@ -133,6 +131,7 @@ OC.L10N.register(
     "Add this as a new category" : "Lisää tämä uutena luokkana",
     "Presentation" : "Esitys",
     "Cinema" : "Elokuvateatteri",
+    "Review" : "Esikatsele",
     "Office" : "Toimisto",
     "Mail" : "Sähköposti",
     "Play" : "Toista",
