@@ -1,7 +1,6 @@
 OC.L10N.register(
     "calendar",
     {
-    "Calendar" : "Kalendar",
     "User-Session unexpectedly expired" : "Korisnička sesija neočekivano je istekla",
     "Provided email-address is not valid" : "Unesena adresa e-pošte nije važeća",
     "%s has published the calendar »%s«" : "%s je objavio kalendar »%s«",
@@ -11,6 +10,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "htjeli bismo vas obavijestiti da je %s objavio kalendar »%s«.",
     "Open »%s«" : "Otvori »%s«",
     "Cheers!" : "Bok!",
+    "Calendar" : "Kalendar",
     "A Calendar app for Nextcloud" : "Aplikacija Kalendar za Nextcloud",
     "Previous day" : "Prethodni dan",
     "Previous week" : "Prethodni tjedan",
@@ -72,7 +72,6 @@ OC.L10N.register(
     "New calendar" : "Novi kalendar",
     "Creating calendar …" : "Stvaranje kalendara ...",
     "New calendar with task list" : "Novi kalendar s popisom zadataka",
-    "New subscription from link" : "Nova pretplata putem poveznice",
     "Creating subscription …" : "Stvaranje pretplate ...",
     "An error occurred, unable to create the calendar." : "Došlo je do pogreške, nije moguće stvoriti kalendar.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Unesite valjanu poveznicu (mora početi s http://, https://, webcal:// ili webcals://)",
@@ -147,8 +146,6 @@ OC.L10N.register(
     "Event title" : "Naslov događaja",
     "All day" : "Cijeli dan",
     "Can not modify all-day setting for events that are part of a recurrence-set." : "Nije moguće mijenjati cjelodnevne postavke za događaje koji su dio skupa ponavljanja.",
-    "from" : "od",
-    "to" : "do",
     "from {startDate}" : "od {startDate}",
     "from {startDate} at {startTime}" : "od {startDate} u {startTime}",
     "to {endDate}" : "do {endDate}",
@@ -284,6 +281,7 @@ OC.L10N.register(
     "Brainstorm" : "Razmišljanje",
     "Baseball" : "Bejzbol",
     "Meet" : "Sastanak",
+    "Review" : "Pregled",
     "Office" : "Ured",
     "Contributor week" : "Tjedan suradnika",
     "Party" : "Tulum",
