@@ -1,7 +1,6 @@
 OC.L10N.register(
     "calendar",
     {
-    "Calendar" : "Календар",
     "Provided email-address is not valid" : "Адресата на е-пошта не е правилно внесена",
     "%s has published the calendar »%s«" : "%s Објави календар »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Неочекувана грешка при испраќање на е-пошта. Контактирајте го администраторот.",
@@ -10,6 +9,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Сакаме да те информираме дека %s објави календар »%s«.",
     "Open »%s«" : "Отвори »%s«",
     "Cheers!" : "Поздрав!",
+    "Calendar" : "Календар",
     "A Calendar app for Nextcloud" : "Календар апликација за Nextcloud",
     "Previous day" : "Предходен ден",
     "Previous week" : "Предходна недела",
@@ -22,7 +22,7 @@ OC.L10N.register(
     "Day" : "Ден",
     "Week" : "Недела",
     "Month" : "Месец",
-    "Untitled calendar" : "Насловен календар",
+    "Untitled calendar" : "Неименуван календар",
     "Edit name" : "Уреди име",
     "Saving name …" : "Зачувување име …",
     "Edit color" : "Уреди бои",
@@ -81,7 +81,9 @@ OC.L10N.register(
     "Automatic" : "Автоматски",
     "Automatic ({detected})" : "Автоматски ({detected})",
     "Enable birthday calendar" : "Овозможи календар со родендени",
+    "Enable simplified editor" : "Овозможи поедноставен уредувач",
     "Show weekends" : "Прикажи викенди",
+    "Show week numbers" : "Прикажи броеви на неделите",
     "Settings & import" : "Параметри & импорт",
     "before at" : "пред",
     "Notification" : "Известување",
@@ -92,6 +94,8 @@ OC.L10N.register(
     "Edit time" : "Удери време",
     "Save time" : "Зачувај време",
     "Remove reminder" : "Одстрани потсетник",
+    "on" : "на",
+    "at" : "во",
     "+ Add reminder" : "+ Додади потсетник",
     "_second_::_seconds_" : ["секунда","секунди"],
     "_minute_::_minutes_" : ["минута","минути"],
@@ -99,7 +103,9 @@ OC.L10N.register(
     "_day_::_days_" : ["ден","дена"],
     "_week_::_weeks_" : ["недела","недели"],
     "No reminders yet" : "Сеуште нема потсетници",
+    "Busy (tentative)" : "Зафатен (привремено)",
     "Busy" : "Зафатен",
+    "Out of office" : "Надвор од канцеларија",
     "Unknown" : "Непознат",
     "{name} accepted your invitation." : "{name} ја прифати вашата покана.",
     "{name} accepted {organizerName}'s invitation." : "{name} ја прифати поканата од {organizerName}.",
@@ -107,37 +113,43 @@ OC.L10N.register(
     "{name} declined {organizerName}'s invitation." : "{name} ја одби поканата од {organizerName}.",
     "{name} did not respond to your invitation yet." : "{name} сеуште нема одговорено на поканата.",
     "{name} did not respond to {organizerName}'s invitation yet." : "{name} сеуште нема одговорено на поканата од {organizerName}.",
+    "Show busy times" : "Прикажи ги зафатените термини",
     "Send e-mail" : "Испрати пошта",
     "Chairperson" : "Претседател",
     "Required participant" : "Задолжителен учесник",
+    "Remove attendee" : "Откажи присутност",
     "Search for e-mails, users, contacts, resources or rooms" : "Пребарувај за е-пошти, корисници, контакти, ресурси или соби",
     "No match found" : "Нема совпаѓања",
     "No attendees yet" : "Сè уште нема присутни",
     "(organizer)" : "(organizer)",
+    "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
     "Event title" : "Наслов на настанот",
     "All day" : "Сите денови",
-    "from" : "од",
-    "to" : "до",
     "from {startDate}" : "од {startDate}",
     "from {startDate} at {startTime}" : "од {startDate} во {startTime}",
     "to {endDate}" : "до {endDate}",
     "to {endDate} at {endTime}" : "до {endDate} во {endTime}",
+    "End repeat" : "Крај на повторувањето",
+    "Select to end repeat" : "Избери крај на повторувањето",
     "never" : "никогаш",
     "on date" : "на датум",
-    "after" : "по",
+    "after" : "после",
     "_time_::_times_" : ["еднаш","пати"],
     "first" : "прв",
     "third" : "трети",
     "fourth" : "четврти",
     "fifth" : "петти",
-    "second to last" : "прв до последен",
+    "second to last" : "втор до последен",
     "last" : "последен",
     "Repeat" : "Повтори",
     "Repeat every" : "Повтори секој",
+    "By day of the month" : "По ден во месецот",
+    "On the" : "На",
     "_month_::_months_" : ["месец","месеци"],
     "_year_::_years_" : ["година","години"],
     "Monday" : "Понеделник",
     "weekday" : "недели",
+    "Summary" : "Резиме",
     "More" : "Повеќе",
     "Save" : "Зачувај",
     "Update" : "Ажурирај",
@@ -145,8 +157,19 @@ OC.L10N.register(
     "Maybe the share was deleted or has expired?" : "Можеби споделувањето е избришано ики рокот му е поминат?",
     "Please select a timezone:" : "Изберете временска зона:",
     "Select Date" : "Избери датум",
+    "from {formattedDate}" : "од {formattedDate}",
+    "to {formattedDate}" : "до {formattedDate}",
+    "on {formattedDate}" : "на {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "од {formattedDate} во {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "до {formattedDate} во {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "на {formattedDate} во {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} во {formattedTime}",
+    "Please enter a valid date" : "Внесете валиден датум",
+    "Please enter a valid date and time" : "Внесете валиден датум и време",
     "Type to search timezone" : "Пребарај временски зони",
     "Personal" : "Лично",
+    "Delete this occurrence" : "Избришете ја оваа можност",
+    "Delete this and all future" : "Избришете го овој и сете во иднина",
     "Details" : "Детали",
     "Attendees" : "Присутни",
     "Reminders" : "Потсетници",
@@ -154,6 +177,7 @@ OC.L10N.register(
     "Projects" : "Проекти",
     "Show more details" : "Прикажи повече детали",
     "Close" : "Затвори",
+    "Subscribe to {name}" : "Претплатете се на {name}",
     "Download {name}" : "Превземи {name}",
     "Anniversary" : "Годишнина",
     "Appointment" : "Назначување",
@@ -178,6 +202,7 @@ OC.L10N.register(
     "{time} after the event ends" : "{time} одкако ќе заврши настанот",
     "on {time}" : "во {time}",
     "on {time} ({timezoneId})" : "во {time} ({timezoneId})",
+    "Week {number} of {year}" : "{number} недела од {year}",
     "Does not repeat" : "Не повторувај",
     "Daily" : "Дневно",
     "Weekly" : "Неделно",
@@ -191,7 +216,11 @@ OC.L10N.register(
     "in {monthNames}" : "во {monthNames}",
     "until {untilDate}" : "до {untilDate}",
     "_%n time_::_%n times_" : ["уште еднаш","%n пати"],
-    "Untitled event" : "Насловен настан",
+    "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
+    "Untitled event" : "Неименуван настан",
+    "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
+    "When shared show only busy" : "Кога е споделено покажи зафатен",
+    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
     "Location" : "Локација",
     "Add a location" : "Додади локација",
     "Description" : "Опис",
@@ -200,9 +229,12 @@ OC.L10N.register(
     "Confirmed" : "Потврдено",
     "Tentative" : "Прелиминарен",
     "Cancelled" : "Откажано",
+    "Confirmation about the overall status of the event." : "Потврда за целокупниот статус на настанот.",
     "Show as" : "Крикажи како",
+    "Take this event into account when calculating free-busy information." : "Го има во предвид овој настан при пресметување на информации за слободен-зафатен.",
     "Free" : "Слободен",
     "Categories" : "Категории",
+    "Categories help you to structure and organize your events." : "Категориите ви помагаат да ги структурирате и организирате вашите настани.",
     "Search or add categories" : "Барај или додади категории",
     "Add this as a new category" : "Додади како нова категорија",
     "Custom color" : "Прилагодена боја",
@@ -220,6 +252,7 @@ OC.L10N.register(
     "Brainstorm" : "Бура",
     "Baseball" : "Бејзбол",
     "Meet" : "Запознавање",
+    "Planning" : "Планирање",
     "Office" : "Канцеларија",
     "Party" : "Забава",
     "Celebration" : "Прослава",
@@ -246,8 +279,10 @@ OC.L10N.register(
     "Studying" : "Учење",
     "Doctor" : "Доктор",
     "Health" : "Здравје",
+    "Dentist" : "Заболекар",
     "Interview" : "Интервју",
     "Training" : "Тренинг",
+    "Practice" : "Пракса",
     "Sports" : "Спорт",
     "Exercise" : "Вежба",
     "Work out" : "Работа",
@@ -280,6 +315,7 @@ OC.L10N.register(
     "Wine tasting" : "Дегустација на вино",
     "Golf" : "Голф",
     "Dinner" : "Вечера",
+    "Lunch" : "Ручек",
     "Global" : "Глобално"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
