@@ -1,12 +1,12 @@
 OC.L10N.register(
     "calendar",
     {
-    "Calendar" : "Calendário",
     "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
     "Hello," : "Olá,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informar que %s publicou o calendário »%s«.",
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "Parabéns!",
+    "Calendar" : "Calendário",
     "Today" : "Hoje",
     "Day" : "Dia",
     "Week" : "Semana",
@@ -27,8 +27,6 @@ OC.L10N.register(
     "Email" : "E-mail",
     "Busy" : "Ocupado",
     "Unknown" : "Desconhecido",
-    "from" : "de",
-    "to" : "para",
     "never" : "nunca",
     "after" : "depois",
     "Repeat" : "Repetir",
@@ -58,6 +56,7 @@ OC.L10N.register(
     "Cancelled" : "Cancelado",
     "Categories" : "Categorias",
     "Presentation" : "Apresentação",
+    "Review" : "Rever",
     "Office" : "Escritório",
     "Mail" : "Correio",
     "Play" : "Reproduzir",
