@@ -1,12 +1,12 @@
 OC.L10N.register(
     "calendar",
     {
-    "Calendar" : "Календар",
     "%s has published the calendar »%s«" : "%s је објавио календар »%s«",
     "Hello," : "Здраво, ",
     "We wanted to inform you that %s has published the calendar »%s«." : "Желимо да Вас обавестимо да је %s објавио календар »%s«.",
     "Open »%s«" : "Отвори »%s«",
     "Cheers!" : "Здраво!",
+    "Calendar" : "Календар",
     "A Calendar app for Nextcloud" : "Календар апликација за Некстклауд",
     "Today" : "Данас",
     "Day" : "Дан",
@@ -15,6 +15,7 @@ OC.L10N.register(
     "Copy private link" : "Копирај приватну везу",
     "Download" : "Преузми",
     "Delete" : "Обриши",
+    "An error occurred, unable to delete the calendar." : "Догодила се грешка, не могу да обришем календар.",
     "Calendar link copied to clipboard." : "Веза календара копирана у оставу.",
     "Calendar link could not be copied to clipboard." : "Веза календара није могла да се копира у оставу.",
     "Share link" : "Дели везу",
@@ -33,8 +34,6 @@ OC.L10N.register(
     "Busy" : "Заузет",
     "Unknown" : "Непознато",
     "All day" : "Цео дан",
-    "from" : "од",
-    "to" : "за",
     "never" : "никада",
     "after" : "након",
     "Repeat" : "Понављај",
@@ -69,6 +68,7 @@ OC.L10N.register(
     "Add this as a new category" : "Додај ово као нову категорију",
     "Movie" : "Филм",
     "Cinema" : "Биоскоп",
+    "Review" : "Претпреглед",
     "Mail" : "поштом",
     "Play" : "Пусти",
     "Dentist" : "Стоматолог",
